@@ -1,8 +1,8 @@
 perc.thr <-
 function(dis,range=seq(0,1,0.01),ptPDF=TRUE,ptPDFname="PercolatedNetwork.pdf",estimPDF=TRUE,estimPDFname="PercThr Estimation.pdf",estimOutfile=TRUE, estimOutName="PercThresholdEstimation.txt",appendOutfile=TRUE,plotALL=FALSE,bgcol="white",label.col="black",label=colnames(dis),modules=FALSE,moduleCol=NA,modFileName="Modules_summary.txt")
 {
-require(igraph)
-require(network)
+#require(igraph)
+#require(network)
 
 salida<-matrix(nrow=length(range),ncol=3)
 colnames(salida)<-c("Threshold","<s>","Clusters")
